# CausaDB Command Line Interface (CLI) and Python Client

This is the CLI and Python client for CausaDB, an easy-to-use platform for building and querying causal AI models in the cloud.

## Documentation

The documentation for the CLI and Python client is available at <https://docs.causadb.com>.

## Installation

To install the CLI and Python client, run

```bash
pip install causadb
```

You can configure your account by running

```bash
causadb account setup
```

You'll be asked for an API key, which you can obtain from the CausaDB team. If you haven't been in touch with the team yet, you can reach out at <mailto:causadb@causa.tech>.